==> v1.4.0.tar.gz: part-db.part-db-server/src/DataTables/Column/SelectColumn.php <==
<?php
/*
 * This file is part of Part-DB (https://github.com/Part-DB/Part-DB-symfony).
 *
 *  Copyright (C) 2019 - 2022 Jan Böhmer (https://github.com/jbtronics)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published
 *  by the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace App\DataTables\Column;

use Omines\DataTablesBundle\Column\AbstractColumn;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * A column representing the checkboxes for select extensions.
 */
class SelectColumn extends AbstractColumn
{
    public function configureOptions(OptionsResolver $resolver): self
    {
        parent::configureOptions($resolver);

        $resolver->setDefaults([
            'label' => '',
            'orderable' => false,
            'searchable' => false,
            'className' => 'select-checkbox no-colvis',
            'visible' => true,
        ]);

        return $this;
    }

    /**
     * @return mixed
     */
    public function normalize($value)
    {
        return $value;
    }

    public function render($value, $context): string
    {
        //Return empty string, as it this column is filled by datatables on client side
        return '';
    }
}

==> v1.7.0.tar.gz: part-db.part-db-server/src/DataTables/Column/SelectColumn.php <==
<?php

declare(strict_types=1);

/*
 * This file is part of Part-DB (https://github.com/Part-DB/Part-DB-symfony).
 *
 *  Copyright (C) 2019 - 2022 Jan Böhmer (https://github.com/jbtronics)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published
 *  by the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
namespace App\DataTables\Column;

use Omines\DataTablesBundle\Column\AbstractColumn;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * A column representing the checkboxes for select extensions.
 */
class SelectColumn extends AbstractColumn
{
    /**
     * @return $this
     */
    public function configureOptions(OptionsResolver $resolver): self
    {
        parent::configureOptions($resolver);

        $resolver->setDefaults([
            'label' => '',
            'orderable' => false,
            'searchable' => false,
            'className' => 'select-checkbox no-colvis',
            'visible' => true,
        ]);

        return $this;
    }

    /**
     * @return mixed
     */
    public function normalize($value): mixed
    {
        return $value;
    }

    public function render($value, $context): string
    {
        //Return empty string, as it this column is filled by datatables on client side
        return '';
    }
}
